//! It's like [core::ops], but more!

mod abs;
pub use abs::*;

mod get_exponent_bits;
pub use get_exponent_bits::*;

mod get_exponent_value;
pub use get_exponent_value::*;

mod ldexp;
pub use ldexp::*;

mod max;
pub use max::*;

mod min;
pub use min::*;

mod truncate;
pub use truncate::*;
